@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Webmozart\Assert\Tests\StaticAnalysis;
 
 use Webmozart\Assert\Assert;
@@ -9,10 +11,8 @@ use Webmozart\Assert\Assert;
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function notSame($value, $expect)
+function notSame($value, $expect): mixed
 {
     Assert::notSame($value, $expect);
 
@@ -24,10 +24,8 @@ function notSame($value, $expect)
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function nullOrNotSame($value, $expect)
+function nullOrNotSame($value, $expect): mixed
 {
     Assert::nullOrNotSame($value, $expect);
 
@@ -39,10 +37,8 @@ function nullOrNotSame($value, $expect)
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function allNotSame($value, $expect)
+function allNotSame($value, $expect): mixed
 {
     Assert::allNotSame($value, $expect);
 
@@ -54,10 +50,8 @@ function allNotSame($value, $expect)
  *
  * @param mixed $value
  * @param mixed $expect
- *
- * @return mixed
  */
-function allNullOrNotSame($value, $expect)
+function allNullOrNotSame($value, $expect): mixed
 {
     Assert::allNullOrNotSame($value, $expect);
 
